==> slack-blocks-0.16.3.crate: slack-blocks-0.16.3/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.16.3 (2021-05-20)


### Features

* image element ([#131](https://github.com/cakekindel/slack-blocks-rs/issues/131)) ([2e61bf8](https://github.com/cakekindel/slack-blocks-rs/commit/2e61bf8d6805bbb8209f5ebae93cc90fcf56a929))

### 0.16.2 (2021-05-20)


### Features

* overflow menu ([#129](https://github.com/cakekindel/slack-blocks-rs/issues/129)) ([6caac5a](https://github.com/cakekindel/slack-blocks-rs/commit/6caac5a14e2d40a3ae0790223c2410b9bcc75cac))

### 0.16.1 (2021-05-19)


### Features

* plaintext input ([#128](https://github.com/cakekindel/slack-blocks-rs/issues/128)) ([aaaf764](https://github.com/cakekindel/slack-blocks-rs/commit/aaaf764331c215d7558e7797a1db670e03fbfad1))

## 0.16.0 (2021-05-19)


### ⚠ BREAKING CHANGES

* radio buttons (#127)

### Features

* radio buttons ([#127](https://github.com/cakekindel/slack-blocks-rs/issues/127)) ([cc743d8](https://github.com/cakekindel/slack-blocks-rs/commit/cc743d881387f0ce24335539c0a5b4bc44914a68))

### 0.15.1 (2021-05-17)


### Bug Fixes

* improve diagnostics of new builder pattern ([#126](https://github.com/cakekindel/slack-blocks-rs/issues/126)) ([bd81a69](https://github.com/cakekindel/slack-blocks-rs/commit/bd81a690b5bd2503439208c61ccbb0cbdb130e4d))

## 0.15.0 (2021-05-17)


### ⚠ BREAKING CHANGES

* static select (#124)

### Features

* static select ([#124](https://github.com/cakekindel/slack-blocks-rs/issues/124)) ([7013c3a](https://github.com/cakekindel/slack-blocks-rs/commit/7013c3ac6da26dc8d5046a67c6dea328e6d5e097))

### 0.14.4 (2021-05-13)


### Features

* select external ([#118](https://github.com/cakekindel/slack-blocks-rs/issues/118)) ([ab2bbda](https://github.com/cakekindel/slack-blocks-rs/commit/ab2bbda4a8f175c1d475fba269eeb69a8a8bfa07))

### 0.14.3 (2021-05-12)


### Features

* add user select ([#117](https://github.com/cakekindel/slack-blocks-rs/issues/117)) ([cea7e32](https://github.com/cakekindel/slack-blocks-rs/commit/cea7e32f15c381cda8f5ae88fba9be3eaafbcc87))

### 0.14.2 (2021-05-11)


### Features

* conversations select ([#116](https://github.com/cakekindel/slack-blocks-rs/issues/116)) ([fd28a6c](https://github.com/cakekindel/slack-blocks-rs/commit/fd28a6cad4c90e9a186fbe98b475c33b0f994f8e))

### 0.14.1 (2021-05-11)

## 0.14.0 (2021-05-11)

### ⚠ BREAKING CHANGES

### Features

* select public channels ([6c87d02](https://github.com/cakekindel/slack-blocks-rs/commit/6c87d02baca43e3751cc42f980e534d41422e242))

## 0.10 - 0.13

* Working out CICD bugs

### 0.9.19 (2021-05-10)

### 0.9.18 (2021-05-10)

### 0.9.17 (2021-05-10)

### 0.9.16 (2021-05-10)

### 0.9.15 (2021-05-10)

### 0.9.14 (2021-05-10)

### 0.9.13 (2021-05-10)

### 0.9.12 (2020-08-06)

### 0.9.11 (2020-07-26)

### 0.9.10 (2020-07-22)


### Features

* confirmation dialog ([#104](https://github.com/cakekindel/slack-blocks-rs/issues/104)) ([be6b2bb](https://github.com/cakekindel/slack-blocks-rs/commit/be6b2bb1beee4ffc41275cc29ebb06cb6e00509f))

### 0.9.9 (2020-07-21)


### Features

* conversation filter ([#86](https://github.com/cakekindel/slack-blocks-rs/issues/86)) ([f0877bc](https://github.com/cakekindel/slack-blocks-rs/commit/f0877bca9f498676f2889f4ff28158cd8a16254a))

### 0.9.8 (2020-07-21)

### 0.9.7 (2020-07-20)

### Features

* option group ([#80](https://github.com/cakekindel/slack-blocks-rs/issues/80)) ([a74fc18](https://github.com/cakekindel/slack-blocks-rs/commit/a74fc18928c6c3250b12d6b1e7e2ec1c46cccdb1))

### 0.9.6 (2020-07-20)

### 0.9.5 (2020-07-20)

### 0.9.4 (2020-07-18)


### Features

* Option composition object ([#69](https://github.com/cakekindel/slack-blocks-rs/issues/69)) ([ccaec03](https://github.com/cakekindel/slack-blocks-rs/commit/ccaec03a0b31e3ea6deb764d0a073ea3ec4fa3fd))

### 0.9.3 (2020-07-18)

### 0.9.2 (2020-07-03)


### Features

* button block element ([#66](https://github.com/cakekindel/slack-blocks-rs/issues/66)) ([8ee12ff](https://github.com/cakekindel/slack-blocks-rs/commit/8ee12ffe3fb509f3f51c383694e33982a4cb3572))

### 0.9.1 (2020-07-03)

## 0.9.0 (2020-06-29)


### ⚠ BREAKING CHANGES

* refactor context block api (#57)

### Features

* refactor context block api ([#57](https://github.com/cakekindel/slack-blocks-rs/issues/57)) ([d407405](https://github.com/cakekindel/slack-blocks-rs/commit/d4074059c21eddafb41a5d8800e272e25a663ebf))

## 0.8.0 (2020-06-29)


### ⚠ BREAKING CHANGES

* rework text (#55)

### Features

* rework text ([#55](https://github.com/cakekindel/slack-blocks-rs/issues/55)) ([3573f44](https://github.com/cakekindel/slack-blocks-rs/commit/3573f4431dc6fc18f6412c783de20782837f2de4))

## 0.7.0 (2020-06-29)


### ⚠ BREAKING CHANGES

* convert Image block contents to match patterns of others (#51)

### Features

* convert Image block contents to match patterns of others ([#51](https://github.com/cakekindel/slack-blocks-rs/issues/51)) ([d127ad6](https://github.com/cakekindel/slack-blocks-rs/commit/d127ad6255a73020d3c27b3293587006e54f4cac))

### 0.6.3 (2020-06-28)

### 0.6.2 (2020-06-28)


### Bug Fixes

* Shrink crate description ([#45](https://github.com/cakekindel/slack-blocks-rs/issues/45)) ([1f331cd](https://github.com/cakekindel/slack-blocks-rs/commit/1f331cdb8f59e163522c627f7356227ce918d976))

### 0.6.1 (2020-06-28)

## 0.6.0 (2020-06-27)


### ⚠ BREAKING CHANGES

* remove public things that shouldn't be public (#40)

### Features

* remove public things that shouldn't be public ([#40](https://github.com/cakekindel/slack-blocks-rs/issues/40)) ([f9fa655](https://github.com/cakekindel/slack-blocks-rs/commit/f9fa65593a1de45e8eb58803e3da102adb011348))

### 0.5.2 (2020-06-27)

### 0.5.1 (2020-06-17)

## 0.5.0 (2020-06-17)


### ⚠ BREAKING CHANGES

* modify section block to follow new patterns (#34)

### Features

* modify section block to follow new patterns ([#34](https://github.com/cakekindel/slack-blocks-rs/issues/34)) ([4d68b22](https://github.com/cakekindel/slack-blocks-rs/commit/4d68b22d7e91463ff01f6790c33644559f1a1ebd))

### 0.4.6 (2020-06-17)


### Features

* file block ([#31](https://github.com/cakekindel/slack-blocks-rs/issues/31)) ([55c1cab](https://github.com/cakekindel/slack-blocks-rs/commit/55c1cabf04a06de93ee82923a32e0ebf4f72e595))

### 0.4.4 (2020-06-17)


### Features

* add input block structure ([#28](https://github.com/cakekindel/slack-blocks-rs/issues/28)) ([de7bdf3](https://github.com/cakekindel/slack-blocks-rs/commit/de7bdf3b5a9e4a279c1919f32f167545463ed5ef))

### 0.4.3 (2020-06-16)

### 0.4.2 (2020-06-16)

### 0.4.1 (2020-06-16)

==> slack-blocks-0.16.4.crate: slack-blocks-0.16.4/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.16.4 (2021-05-20)


### Features

* date picker element ([#132](https://github.com/cakekindel/slack-blocks-rs/issues/132)) ([44e72ab](https://github.com/cakekindel/slack-blocks-rs/commit/44e72ab824ace1810f28421b6ec3594c9eeae695))

### 0.16.3 (2021-05-20)


### Features

* image element ([#131](https://github.com/cakekindel/slack-blocks-rs/issues/131)) ([2e61bf8](https://github.com/cakekindel/slack-blocks-rs/commit/2e61bf8d6805bbb8209f5ebae93cc90fcf56a929))

### 0.16.2 (2021-05-20)


### Features

* overflow menu ([#129](https://github.com/cakekindel/slack-blocks-rs/issues/129)) ([6caac5a](https://github.com/cakekindel/slack-blocks-rs/commit/6caac5a14e2d40a3ae0790223c2410b9bcc75cac))

### 0.16.1 (2021-05-19)


### Features

* plaintext input ([#128](https://github.com/cakekindel/slack-blocks-rs/issues/128)) ([aaaf764](https://github.com/cakekindel/slack-blocks-rs/commit/aaaf764331c215d7558e7797a1db670e03fbfad1))

## 0.16.0 (2021-05-19)


### ⚠ BREAKING CHANGES

* radio buttons (#127)

### Features

* radio buttons ([#127](https://github.com/cakekindel/slack-blocks-rs/issues/127)) ([cc743d8](https://github.com/cakekindel/slack-blocks-rs/commit/cc743d881387f0ce24335539c0a5b4bc44914a68))

### 0.15.1 (2021-05-17)


### Bug Fixes

* improve diagnostics of new builder pattern ([#126](https://github.com/cakekindel/slack-blocks-rs/issues/126)) ([bd81a69](https://github.com/cakekindel/slack-blocks-rs/commit/bd81a690b5bd2503439208c61ccbb0cbdb130e4d))

## 0.15.0 (2021-05-17)


### ⚠ BREAKING CHANGES

* static select (#124)

### Features

* static select ([#124](https://github.com/cakekindel/slack-blocks-rs/issues/124)) ([7013c3a](https://github.com/cakekindel/slack-blocks-rs/commit/7013c3ac6da26dc8d5046a67c6dea328e6d5e097))

### 0.14.4 (2021-05-13)


### Features

* select external ([#118](https://github.com/cakekindel/slack-blocks-rs/issues/118)) ([ab2bbda](https://github.com/cakekindel/slack-blocks-rs/commit/ab2bbda4a8f175c1d475fba269eeb69a8a8bfa07))

### 0.14.3 (2021-05-12)


### Features

* add user select ([#117](https://github.com/cakekindel/slack-blocks-rs/issues/117)) ([cea7e32](https://github.com/cakekindel/slack-blocks-rs/commit/cea7e32f15c381cda8f5ae88fba9be3eaafbcc87))

### 0.14.2 (2021-05-11)


### Features

* conversations select ([#116](https://github.com/cakekindel/slack-blocks-rs/issues/116)) ([fd28a6c](https://github.com/cakekindel/slack-blocks-rs/commit/fd28a6cad4c90e9a186fbe98b475c33b0f994f8e))

### 0.14.1 (2021-05-11)

## 0.14.0 (2021-05-11)

### ⚠ BREAKING CHANGES

### Features

* select public channels ([6c87d02](https://github.com/cakekindel/slack-blocks-rs/commit/6c87d02baca43e3751cc42f980e534d41422e242))

## 0.10 - 0.13

* Working out CICD bugs

### 0.9.19 (2021-05-10)

### 0.9.18 (2021-05-10)

### 0.9.17 (2021-05-10)

### 0.9.16 (2021-05-10)

### 0.9.15 (2021-05-10)

### 0.9.14 (2021-05-10)

### 0.9.13 (2021-05-10)

### 0.9.12 (2020-08-06)

### 0.9.11 (2020-07-26)

### 0.9.10 (2020-07-22)


### Features

* confirmation dialog ([#104](https://github.com/cakekindel/slack-blocks-rs/issues/104)) ([be6b2bb](https://github.com/cakekindel/slack-blocks-rs/commit/be6b2bb1beee4ffc41275cc29ebb06cb6e00509f))

### 0.9.9 (2020-07-21)


### Features

* conversation filter ([#86](https://github.com/cakekindel/slack-blocks-rs/issues/86)) ([f0877bc](https://github.com/cakekindel/slack-blocks-rs/commit/f0877bca9f498676f2889f4ff28158cd8a16254a))

### 0.9.8 (2020-07-21)

### 0.9.7 (2020-07-20)

### Features

* option group ([#80](https://github.com/cakekindel/slack-blocks-rs/issues/80)) ([a74fc18](https://github.com/cakekindel/slack-blocks-rs/commit/a74fc18928c6c3250b12d6b1e7e2ec1c46cccdb1))

### 0.9.6 (2020-07-20)

### 0.9.5 (2020-07-20)

### 0.9.4 (2020-07-18)


### Features

* Option composition object ([#69](https://github.com/cakekindel/slack-blocks-rs/issues/69)) ([ccaec03](https://github.com/cakekindel/slack-blocks-rs/commit/ccaec03a0b31e3ea6deb764d0a073ea3ec4fa3fd))

### 0.9.3 (2020-07-18)

### 0.9.2 (2020-07-03)


### Features

* button block element ([#66](https://github.com/cakekindel/slack-blocks-rs/issues/66)) ([8ee12ff](https://github.com/cakekindel/slack-blocks-rs/commit/8ee12ffe3fb509f3f51c383694e33982a4cb3572))

### 0.9.1 (2020-07-03)

## 0.9.0 (2020-06-29)


### ⚠ BREAKING CHANGES

* refactor context block api (#57)

### Features

* refactor context block api ([#57](https://github.com/cakekindel/slack-blocks-rs/issues/57)) ([d407405](https://github.com/cakekindel/slack-blocks-rs/commit/d4074059c21eddafb41a5d8800e272e25a663ebf))

## 0.8.0 (2020-06-29)


### ⚠ BREAKING CHANGES

* rework text (#55)

### Features

* rework text ([#55](https://github.com/cakekindel/slack-blocks-rs/issues/55)) ([3573f44](https://github.com/cakekindel/slack-blocks-rs/commit/3573f4431dc6fc18f6412c783de20782837f2de4))

## 0.7.0 (2020-06-29)


### ⚠ BREAKING CHANGES

* convert Image block contents to match patterns of others (#51)

### Features

* convert Image block contents to match patterns of others ([#51](https://github.com/cakekindel/slack-blocks-rs/issues/51)) ([d127ad6](https://github.com/cakekindel/slack-blocks-rs/commit/d127ad6255a73020d3c27b3293587006e54f4cac))

### 0.6.3 (2020-06-28)

### 0.6.2 (2020-06-28)


### Bug Fixes

* Shrink crate description ([#45](https://github.com/cakekindel/slack-blocks-rs/issues/45)) ([1f331cd](https://github.com/cakekindel/slack-blocks-rs/commit/1f331cdb8f59e163522c627f7356227ce918d976))

### 0.6.1 (2020-06-28)

## 0.6.0 (2020-06-27)


### ⚠ BREAKING CHANGES

* remove public things that shouldn't be public (#40)

### Features

* remove public things that shouldn't be public ([#40](https://github.com/cakekindel/slack-blocks-rs/issues/40)) ([f9fa655](https://github.com/cakekindel/slack-blocks-rs/commit/f9fa65593a1de45e8eb58803e3da102adb011348))

### 0.5.2 (2020-06-27)

### 0.5.1 (2020-06-17)

## 0.5.0 (2020-06-17)


### ⚠ BREAKING CHANGES

* modify section block to follow new patterns (#34)

### Features

* modify section block to follow new patterns ([#34](https://github.com/cakekindel/slack-blocks-rs/issues/34)) ([4d68b22](https://github.com/cakekindel/slack-blocks-rs/commit/4d68b22d7e91463ff01f6790c33644559f1a1ebd))

### 0.4.6 (2020-06-17)


### Features

* file block ([#31](https://github.com/cakekindel/slack-blocks-rs/issues/31)) ([55c1cab](https://github.com/cakekindel/slack-blocks-rs/commit/55c1cabf04a06de93ee82923a32e0ebf4f72e595))

### 0.4.4 (2020-06-17)


### Features

* add input block structure ([#28](https://github.com/cakekindel/slack-blocks-rs/issues/28)) ([de7bdf3](https://github.com/cakekindel/slack-blocks-rs/commit/de7bdf3b5a9e4a279c1919f32f167545463ed5ef))

### 0.4.3 (2020-06-16)

### 0.4.2 (2020-06-16)

### 0.4.1 (2020-06-16)
